package com.goldenwater.slgc.mapper;

import java.util.List;
import com.goldenwater.slgc.domain.PlayerItem;
import org.apache.ibatis.annotations.Mapper;

/** 播放器项目 Mapper */
@Mapper
public interface PlayerItemMapper {
    /**
     * 查询播放器项目列表
     *
     * @param playerItem 查询条件
     * @return 播放器项目列表
     */
    public List<PlayerItem> selectPlayerItemList(PlayerItem playerItem);

    /**
     * 通过项目ID查询播放器项目
     *
     * @param id 项目ID
     * @return 播放器项目
     */
    public PlayerItem selectPlayerItemById(String id);

    /**
     * 通过项目ID删除播放器项目
     *
     * @param id 项目ID
     * @return 影响行数
     */
    public int deletePlayerItemById(String id);

    /**
     * 批量删除播放器项目
     *
     * @param ids 项目ID数组
     * @return 影响行数
     */
    public int deletePlayerItemByIds(String[] ids);

    /**
     * 修改播放器项目
     *
     * @param playerItem 播放器项目
     * @return 影响行数
     */
    public int updatePlayerItem(PlayerItem playerItem);

    /**
     * 新增播放器项目
     *
     * @param playerItem 播放器项目
     * @return 影响行数
     */
    public int insertPlayerItem(PlayerItem playerItem);

    /**
     * 查询所有播放器项目
     *
     * @return 播放器项目列表
     */
    public List<PlayerItem> selectAll();

    /**
     * 根据播放器ID删除项目
     *
     * @param plyId 播放器ID
     * @return 影响行数
     */
    public int deleteByPlyId(String plyId);
}
